@@ -7,7 +7,7 @@ from .importlib_interface import \
 from .interface import \
     ResourceNotAvailable, Resource, ResourceManagerInterface, ResourceManager, \
     get_global_manager, set_global_manager, temp_manager, add_manager, remove_manager, \
-    clear, register, register_data, register_directory, unregister, has_resource, \
+    clear, register_resource, register, register_data, register_directory, unregister, has_resource, \
     get_resources, get_resource, get_binary, get_text, registered_datas, \
     MISSING
 
